projectal.entities.booking API documentation

# projectal.entities.booking

View Source

     1from projectal.entity import Entity
     2from projectal.linkers import *
     3
     4
     5class Booking(Entity, StageLinker, TagLinker):
     6    """
     7    Implementation of the [Booking](https://projectal.com/docs/latest/#tag/Booking) API.
     8    """
     9    _path = 'booking'
    10    _name = 'booking'
    11    _links = [StageLinker, TagLinker]

class Booking(projectal.entity.Entity, projectal.linkers.StageLinker, projectal.linkers.TagLinker): View Source

     6class Booking(Entity, StageLinker, TagLinker):
     7    """
     8    Implementation of the [Booking](https://projectal.com/docs/latest/#tag/Booking) API.
     9    """
    10    _path = 'booking'
    11    _name = 'booking'
    12    _links = [StageLinker, TagLinker]

Implementation of the Booking API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.StageLinker
  link_stage
  unlink_stage
projectal.linkers.TagLinker
  link_tag
  unlink_tag
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy